cat >> $HGRCPATH <<EOF
[extensions]
narrow=
[experimental]
changegroup3 = True
EOF
